#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.9
visibility:           public
id:                   murmur-hash-0.1.0.9-493u58tDLeoHWKW9um8pv0
key:                  murmur-hash-0.1.0.9-493u58tDLeoHWKW9um8pv0
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  df9e940328a5c8cfd19d89c00c691490
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-8.10.5/site-local/murmur-hash-0.1.0.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/murmur-hash-0.1.0.9
hs-libraries:         HSmurmur-hash-0.1.0.9-493u58tDLeoHWKW9um8pv0
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

